==> amity-sdk-7.12.8-sources.jar: main/com/amity/socialcloud/sdk/api/core/AmityCoreClient.kt <==
package com.amity.socialcloud.sdk.api.core

import com.amity.socialcloud.sdk.api.core.ads.AmityAdRepository
import com.amity.socialcloud.sdk.api.core.encryption.AmityDBEncryption
import com.amity.socialcloud.sdk.api.core.endpoint.AmityEndpoint
import com.amity.socialcloud.sdk.api.core.events.AmityTopicSubscription
import com.amity.socialcloud.sdk.api.core.file.AmityFileRepository
import com.amity.socialcloud.sdk.api.core.invitation.AmityInvitationRepository
import com.amity.socialcloud.sdk.api.core.notification.AmityNotification
import com.amity.socialcloud.sdk.api.core.notificationtray.AmityNotificationTray
import com.amity.socialcloud.sdk.api.core.permission.AmityPermissionValidator
import com.amity.socialcloud.sdk.api.core.presence.AmityPresenceService
import com.amity.socialcloud.sdk.api.core.presence.AmityRoomPresenceRepository
import com.amity.socialcloud.sdk.api.core.presence.AmityUserPresenceRepository
import com.amity.socialcloud.sdk.api.core.reaction.AmityLiveReactionRepository
import com.amity.socialcloud.sdk.api.core.reaction.AmityReactionRepository
import com.amity.socialcloud.sdk.api.core.session.AmitySessionEstablisher
import com.amity.socialcloud.sdk.api.core.session.AmityVisitorEstablisher
import com.amity.socialcloud.sdk.api.core.shareablelink.AmityShareableLink
import com.amity.socialcloud.sdk.api.core.user.AmityUserRepository
import com.amity.socialcloud.sdk.api.core.user.update.AmityUserUpdate
import com.amity.socialcloud.sdk.core.CoreClient
import com.amity.socialcloud.sdk.core.domain.networksettings.GetUserSettingsUseCase
import com.amity.socialcloud.sdk.core.domain.networksettings.ValidateTextsUseCase
import com.amity.socialcloud.sdk.core.domain.networksettings.ValidateUrlsUseCase
import com.amity.socialcloud.sdk.core.domain.notification.RegisterDeviceForNotificationUseCase
import com.amity.socialcloud.sdk.core.domain.notification.UnregisterAllUsersForNotificationUseCase
import com.amity.socialcloud.sdk.core.domain.session.ActiveUserIdGetUseCase
import com.amity.socialcloud.sdk.core.domain.session.ActiveUserTypeGetUseCase
import com.amity.socialcloud.sdk.core.domain.session.LogoutUseCase
import com.amity.socialcloud.sdk.core.domain.session.SecureLogoutUseCase
import com.amity.socialcloud.sdk.core.domain.session.VisitorDeviceIdGetUseCase
import com.amity.socialcloud.sdk.core.session.model.SessionState
import com.amity.socialcloud.sdk.model.core.content.AmityContentCheck
import com.amity.socialcloud.sdk.model.core.events.AmityTopic
import com.amity.socialcloud.sdk.model.core.file.AmityFileAccessType
import com.amity.socialcloud.sdk.model.core.permission.AmityPermission
import com.amity.socialcloud.sdk.model.core.session.AmityGlobalBanEvent
import com.amity.socialcloud.sdk.model.core.session.SessionHandler
import com.amity.socialcloud.sdk.model.core.settings.AmityCoreUserSettings
import com.amity.socialcloud.sdk.model.core.unread.UserUnread
import com.amity.socialcloud.sdk.model.core.user.AmityUser
import com.amity.socialcloud.sdk.model.core.user.AmityUserType
import com.amity.socialcloud.sdk.streamapi.AmityClientConfiguration
import com.amity.socialcloud.sdk.video.data.stream.StreamFunction
import com.ekoapp.ekosdk.internal.api.http.AmityNetworkActivity
import com.ekoapp.ekosdk.internal.usecase.content.GetContentCheckUseCase
import com.ekoapp.ekosdk.sdk.BuildConfig
import com.hivemq.client.mqtt.MqttClientState
import io.reactivex.rxjava3.core.Completable
import io.reactivex.rxjava3.core.Flowable
import io.reactivex.rxjava3.core.Single

object AmityCoreClient {

    /* begin_public_function
	  id: client.read_session_state
	*/
    fun getCurrentSessionState(): SessionState {
        return CoreClient.currentSessionState
    }
    /* end_public_function */

    /**
     * This method setup the SDK by overriding default endpoints
     *
     * @param apiKey an api key to be used with the SDK
     * @param endpoint an endpoint model to override default endpoints
     *
     */
    fun setup(
        apiKey: String,
        endpoint: AmityEndpoint = AmityEndpoint.SG,
        dbEncryption: AmityDBEncryption = AmityDBEncryption.NONE
    ): Completable {
        return CoreClient.setup(apiKey, endpoint, dbEncryption)
    }

    /* begin_public_function
	  id: client.register_push
	*/
    fun registerPushNotification(): Completable {
        return if (getCurrentUserType() == AmityUserType.SIGNED_IN) {
            RegisterDeviceForNotificationUseCase().execute()
        } else {
            Completable.complete() // No-op for visitor/bot users
        }
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.unregister_push
	*/
    fun unregisterPushNotification(): Completable {
        return if (getCurrentUserType() == AmityUserType.SIGNED_IN) {
            UnregisterAllUsersForNotificationUseCase().execute()
        } else {
            Completable.complete() // No-op for visitor/bot users
        }
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.disconnect
	*/
    fun disconnect(): Completable {
        return CoreClient.disconnect()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.login
	  api_style: async
	*/
    fun login(userId: String, sessionHandler: SessionHandler?): AmitySessionEstablisher.Builder {
        return CoreClient.login(userId, sessionHandler)
    }
    /* end_public_function */

    fun loginAsVisitor(sessionHandler: SessionHandler): AmityVisitorEstablisher.Builder {
        return CoreClient.loginAsVisitor(sessionHandler)
    }

    /* begin_public_function
	  id: client.logout
	*/
    fun logout(): Completable {
        return LogoutUseCase().execute()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.secure_logout
	*/
    fun secureLogout(): Completable {
        return SecureLogoutUseCase().execute()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.get_current_user
	*/
    fun getUserId(): String {
        return ActiveUserIdGetUseCase().execute()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.update_user
	  api_style: async
	*/
    fun editUser(): AmityUserUpdate.Builder {
        return AmityUserUpdate.Builder(getUserId())
    }
    /* end_public_function */

    fun hasPermission(permission: AmityPermission): AmityPermissionValidator {
        return AmityPermissionValidator(permission)
    }

    fun getCurrentUser(): Flowable<AmityUser> {
        return newUserRepository().getUser(getUserId())
    }

    fun newUserRepository(): AmityUserRepository {
        return AmityUserRepository()
    }

    fun newAdRepository(): AmityAdRepository {
        return AmityAdRepository()
    }

    fun newFileRepository(): AmityFileRepository {
        return AmityFileRepository()
    }

    fun newReactionRepository(): AmityReactionRepository {
        return AmityReactionRepository()
    }

    fun newLiveReactionRepository(): AmityLiveReactionRepository {
        return AmityLiveReactionRepository()
    }

    fun newInvitationRepository(): AmityInvitationRepository {
        return AmityInvitationRepository()
    }

    fun getAmityCoreSdkVersion(): String {
        return BuildConfig.VERSION_NAME
    }

    fun getGlobalBanEvents(): Flowable<AmityGlobalBanEvent> {
        return Flowable.never()
    }

    /* begin_public_function
	  id: client.notifications
	*/
    fun notifications(): AmityNotification {
        return AmityNotification()
    }
    /* end_public_function */

    /* begin_public_function
    id: client.notificationTray
  */
    fun notificationTray(): AmityNotificationTray {
        return AmityNotificationTray()
    }
    /* end_public_function */

    /* begin_public_function
    id: client.notificationTray
  */
    fun getShareableLinkConfiguration(): AmityShareableLink {
        return AmityShareableLink()
    }
    /* end_public_function */

    fun getConfiguration(): AmityClientConfiguration {
        return AmityClientConfiguration(StreamFunction())
    }

    fun subscription(topic: AmityTopic): AmityTopicSubscription {
        return AmityTopicSubscription(topic)
    }

    fun getContentCheck(): Single<AmityContentCheck> {
        return GetContentCheckUseCase().execute()
    }

    /* begin_public_function
	  id: client.observe_session_state
	  api_style: value_observation
	*/
    fun observeSessionState(): Flowable<SessionState> {
        return CoreClient.observeSessionState()
    }
    /* end_public_function */

    fun observeUserUnread(): Flowable<UserUnread> {
        return CoreClient.observeUserUnread()
    }

    fun presence(): AmityPresenceService {
        return CoreClient.presence()
    }

    fun newUserPresenceRepository(): AmityUserPresenceRepository {
        return CoreClient.newUserPresenceRepository()
    }

    fun newRoomPresenceRepository(): AmityRoomPresenceRepository.Builder {
        return CoreClient.newRoomPresenceRepository()
    }

    fun enableUnreadCount() {
        CoreClient.enableUnreadCount()
    }

    fun validateUrls(urls: List<String>) : Completable {
        return ValidateUrlsUseCase().execute(urls)
    }

    fun validateTexts(texts: List<String>) : Completable {
        return ValidateTextsUseCase().execute(texts)
    }

    fun setUploadedFileAccessType(type: AmityFileAccessType) {
        CoreClient.setUploadedFileAccessType(type)
    }

    fun getUploadedFileAccessType(): AmityFileAccessType {
        return CoreClient.getUploadedFileAccessType()
    }

    fun getAccessToken(): String? {
        return CoreClient.getAccessToken()
    }

    fun observeNetworkActivities(): Flowable<AmityNetworkActivity> {
        return CoreClient.observeNetworkActivities()
    }

    fun getCoreUserSettings() : Flowable<AmityCoreUserSettings>{
        return GetUserSettingsUseCase().execute()
    }

    fun getVisitorDeviceId(): String {
        return VisitorDeviceIdGetUseCase().execute()
    }

    fun getCurrentUserType(): AmityUserType {
        return ActiveUserTypeGetUseCase().execute()
    }

}

==> amity-sdk-7.14.1-sources.jar: main/com/amity/socialcloud/sdk/api/core/AmityCoreClient.kt <==
package com.amity.socialcloud.sdk.api.core

import com.amity.socialcloud.sdk.api.core.ads.AmityAdRepository
import com.amity.socialcloud.sdk.api.core.encryption.AmityDBEncryption
import com.amity.socialcloud.sdk.api.core.endpoint.AmityEndpoint
import com.amity.socialcloud.sdk.api.core.events.AmityTopicSubscription
import com.amity.socialcloud.sdk.api.core.file.AmityFileRepository
import com.amity.socialcloud.sdk.api.core.invitation.AmityInvitationRepository
import com.amity.socialcloud.sdk.api.core.notification.AmityNotification
import com.amity.socialcloud.sdk.api.core.notificationtray.AmityNotificationTray
import com.amity.socialcloud.sdk.api.core.permission.AmityPermissionValidator
import com.amity.socialcloud.sdk.api.core.presence.AmityPresenceService
import com.amity.socialcloud.sdk.api.core.presence.AmityRoomPresenceRepository
import com.amity.socialcloud.sdk.api.core.presence.AmityUserPresenceRepository
import com.amity.socialcloud.sdk.api.core.reaction.AmityLiveReactionRepository
import com.amity.socialcloud.sdk.api.core.reaction.AmityReactionRepository
import com.amity.socialcloud.sdk.api.core.session.AmitySessionEstablisher
import com.amity.socialcloud.sdk.api.core.session.AmityVisitorEstablisher
import com.amity.socialcloud.sdk.api.core.shareablelink.AmityShareableLink
import com.amity.socialcloud.sdk.api.core.user.AmityUserRepository
import com.amity.socialcloud.sdk.api.core.user.update.AmityUserUpdate
import com.amity.socialcloud.sdk.core.CoreClient
import com.amity.socialcloud.sdk.core.domain.networksettings.GetUserSettingsUseCase
import com.amity.socialcloud.sdk.core.domain.networksettings.ValidateTextsUseCase
import com.amity.socialcloud.sdk.core.domain.networksettings.ValidateUrlsUseCase
import com.amity.socialcloud.sdk.core.domain.link.GetLinkPreviewMetadataUseCase
import com.amity.socialcloud.sdk.core.domain.notification.RegisterDeviceForNotificationUseCase
import com.amity.socialcloud.sdk.core.domain.notification.UnregisterAllUsersForNotificationUseCase
import com.amity.socialcloud.sdk.core.domain.session.ActiveUserIdGetUseCase
import com.amity.socialcloud.sdk.core.domain.session.ActiveUserTypeGetUseCase
import com.amity.socialcloud.sdk.core.domain.session.LogoutUseCase
import com.amity.socialcloud.sdk.core.domain.session.SecureLogoutUseCase
import com.amity.socialcloud.sdk.core.domain.session.VisitorDeviceIdGetUseCase
import com.amity.socialcloud.sdk.core.session.model.SessionState
import com.amity.socialcloud.sdk.model.core.content.AmityContentCheck
import com.amity.socialcloud.sdk.model.core.events.AmityTopic
import com.amity.socialcloud.sdk.model.core.file.AmityFileAccessType
import com.amity.socialcloud.sdk.model.core.link.AmityLinkPreviewMetadata
import com.amity.socialcloud.sdk.model.core.permission.AmityPermission
import com.amity.socialcloud.sdk.model.core.session.AmityGlobalBanEvent
import com.amity.socialcloud.sdk.model.core.session.SessionHandler
import com.amity.socialcloud.sdk.model.core.settings.AmityCoreUserSettings
import com.amity.socialcloud.sdk.model.core.unread.UserUnread
import com.amity.socialcloud.sdk.model.core.user.AmityUser
import com.amity.socialcloud.sdk.model.core.user.AmityUserType
import com.amity.socialcloud.sdk.streamapi.AmityClientConfiguration
import com.amity.socialcloud.sdk.video.data.stream.StreamFunction
import com.ekoapp.ekosdk.internal.api.http.AmityNetworkActivity
import com.ekoapp.ekosdk.internal.usecase.content.GetContentCheckUseCase
import com.ekoapp.ekosdk.sdk.BuildConfig
import com.hivemq.client.mqtt.MqttClientState
import io.reactivex.rxjava3.core.Completable
import io.reactivex.rxjava3.core.Flowable
import io.reactivex.rxjava3.core.Single

object AmityCoreClient {

    /* begin_public_function
	  id: client.read_session_state
	*/
    fun getCurrentSessionState(): SessionState {
        return CoreClient.currentSessionState
    }
    /* end_public_function */

    /**
     * This method setup the SDK by overriding default endpoints
     *
     * @param apiKey an api key to be used with the SDK
     * @param endpoint an endpoint model to override default endpoints
     *
     */
    fun setup(
        apiKey: String,
        endpoint: AmityEndpoint = AmityEndpoint.SG,
        dbEncryption: AmityDBEncryption = AmityDBEncryption.NONE
    ): Completable {
        return CoreClient.setup(apiKey, endpoint, dbEncryption)
    }

    /* begin_public_function
	  id: client.register_push
	*/
    fun registerPushNotification(): Completable {
        return if (getCurrentUserType() == AmityUserType.SIGNED_IN) {
            RegisterDeviceForNotificationUseCase().execute()
        } else {
            Completable.complete() // No-op for visitor/bot users
        }
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.unregister_push
	*/
    fun unregisterPushNotification(): Completable {
        return if (getCurrentUserType() == AmityUserType.SIGNED_IN) {
            UnregisterAllUsersForNotificationUseCase().execute()
        } else {
            Completable.complete() // No-op for visitor/bot users
        }
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.disconnect
	*/
    fun disconnect(): Completable {
        return CoreClient.disconnect()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.login
	  api_style: async
	*/
    fun login(userId: String, sessionHandler: SessionHandler?): AmitySessionEstablisher.Builder {
        return CoreClient.login(userId, sessionHandler)
    }
    /* end_public_function */

    fun loginAsVisitor(sessionHandler: SessionHandler): AmityVisitorEstablisher.Builder {
        return CoreClient.loginAsVisitor(sessionHandler)
    }

    /* begin_public_function
	  id: client.logout
	*/
    fun logout(): Completable {
        return LogoutUseCase().execute()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.secure_logout
	*/
    fun secureLogout(): Completable {
        return SecureLogoutUseCase().execute()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.get_current_user
	*/
    fun getUserId(): String {
        return ActiveUserIdGetUseCase().execute()
    }
    /* end_public_function */

    /* begin_public_function
	  id: client.update_user
	  api_style: async
	*/
    fun editUser(): AmityUserUpdate.Builder {
        return AmityUserUpdate.Builder(getUserId())
    }
    /* end_public_function */

    fun hasPermission(permission: AmityPermission): AmityPermissionValidator {
        return AmityPermissionValidator(permission)
    }

    fun getCurrentUser(): Flowable<AmityUser> {
        return newUserRepository().getUser(getUserId())
    }

    fun newUserRepository(): AmityUserRepository {
        return AmityUserRepository()
    }

    fun newAdRepository(): AmityAdRepository {
        return AmityAdRepository()
    }

    fun newFileRepository(): AmityFileRepository {
        return AmityFileRepository()
    }

    fun newReactionRepository(): AmityReactionRepository {
        return AmityReactionRepository()
    }

    fun newLiveReactionRepository(): AmityLiveReactionRepository {
        return AmityLiveReactionRepository()
    }

    fun newInvitationRepository(): AmityInvitationRepository {
        return AmityInvitationRepository()
    }

    fun getAmityCoreSdkVersion(): String {
        return BuildConfig.VERSION_NAME
    }

    fun getGlobalBanEvents(): Flowable<AmityGlobalBanEvent> {
        return Flowable.never()
    }

    /* begin_public_function
	  id: client.notifications
	*/
    fun notifications(): AmityNotification {
        return AmityNotification()
    }
    /* end_public_function */

    /* begin_public_function
    id: client.notificationTray
  */
    fun notificationTray(): AmityNotificationTray {
        return AmityNotificationTray()
    }
    /* end_public_function */

    /* begin_public_function
    id: client.notificationTray
  */
    fun getShareableLinkConfiguration(): AmityShareableLink {
        return AmityShareableLink()
    }
    /* end_public_function */

    fun getConfiguration(): AmityClientConfiguration {
        return AmityClientConfiguration(StreamFunction())
    }

    fun subscription(topic: AmityTopic): AmityTopicSubscription {
        return AmityTopicSubscription(topic)
    }

    fun getContentCheck(): Single<AmityContentCheck> {
        return GetContentCheckUseCase().execute()
    }

    /* begin_public_function
	  id: client.observe_session_state
	  api_style: value_observation
	*/
    fun observeSessionState(): Flowable<SessionState> {
        return CoreClient.observeSessionState()
    }
    /* end_public_function */

    fun observeUserUnread(): Flowable<UserUnread> {
        return CoreClient.observeUserUnread()
    }

    fun presence(): AmityPresenceService {
        return CoreClient.presence()
    }

    fun newUserPresenceRepository(): AmityUserPresenceRepository {
        return CoreClient.newUserPresenceRepository()
    }

    fun newRoomPresenceRepository(): AmityRoomPresenceRepository.Builder {
        return CoreClient.newRoomPresenceRepository()
    }

    fun enableUnreadCount() {
        CoreClient.enableUnreadCount()
    }

    fun validateUrls(urls: List<String>) : Completable {
        return ValidateUrlsUseCase().execute(urls)
    }

    fun validateTexts(texts: List<String>) : Completable {
        return ValidateTextsUseCase().execute(texts)
    }

    fun setUploadedFileAccessType(type: AmityFileAccessType) {
        CoreClient.setUploadedFileAccessType(type)
    }

    fun getUploadedFileAccessType(): AmityFileAccessType {
        return CoreClient.getUploadedFileAccessType()
    }

    fun getAccessToken(): String? {
        return CoreClient.getAccessToken()
    }

    fun observeNetworkActivities(): Flowable<AmityNetworkActivity> {
        return CoreClient.observeNetworkActivities()
    }

    fun getCoreUserSettings() : Flowable<AmityCoreUserSettings>{
        return GetUserSettingsUseCase().execute()
    }

    fun getVisitorDeviceId(): String {
        return VisitorDeviceIdGetUseCase().execute()
    }

    fun getCurrentUserType(): AmityUserType {
        return ActiveUserTypeGetUseCase().execute()
    }

    /* begin_public_function
      id: client.fetch_link_preview
      api_style: async
    */
    /**
     * Gets link preview metadata for a given URL
     * @param [url] the URL to get preview metadata for
     * @return Single<AmityLinkPreviewMetadata> containing title, imageUrl, and domain
     */
    fun getLinkPreviewMetadata(url: String): Single<AmityLinkPreviewMetadata> {
        return GetLinkPreviewMetadataUseCase().execute(url)
    }
    /* end_public_function */
}
